@@ -13,7 +13,6 @@ from shutil import rmtree
 from typing import TYPE_CHECKING, Any
 
 import pytest
-from ansible.plugins.loader import module_loader
 from packaging.version import Version
 
 from ansible_compat.constants import INVALID_PREREQUISITES_RC
@@ -400,7 +399,7 @@ def test__update_env(
 
 
 def test_require_collection_wrong_version(runtime: Runtime) -> None:
-    """Tests behaviour of require_collection."""
+    """Tests behavior of require_collection."""
     subprocess.check_output(
         [
             "ansible-galaxy",
@@ -472,7 +471,7 @@ def test_require_collection_missing(
     install: bool,
     runtime: Runtime,
 ) -> None:
-    """Tests behaviour of require_collection, missing case."""
+    """Tests behavior of require_collection, missing case."""
     with pytest.raises(AnsibleCompatError) as pytest_wrapped_e:
         runtime.require_collection(name=name, version=version, install=install)
     assert pytest_wrapped_e.type == InvalidPrerequisiteError
@@ -637,7 +636,7 @@ def test_upgrade_collection(runtime_tmp: Runtime) -> None:
     # ensure that we inject our tmp folders in ansible paths
     runtime_tmp.prepare_environment()
 
-    # we install specific oudated version of a collection
+    # we install specific outdated version of a collection
     runtime_tmp.install_collection("examples/reqs_v2/community-molecule-0.1.0.tar.gz")
     with pytest.raises(
         InvalidPrerequisiteError,
@@ -758,19 +757,11 @@ def test_load_plugins(
 ) -> None:
     """Tests ability to load plugin from a collection installed by requirement."""
     with cwd(Path(path)):
-        from ansible_compat.prerun import get_cache_dir
-
-        rmtree(get_cache_dir(Path.cwd()), ignore_errors=True)
         runtime = Runtime(isolated=True, require_module=True)
         runtime.prepare_environment(install_local=True)
         for plugin_name in expected_plugins:
-            loaded_module = module_loader.find_plugin_with_context(
-                plugin_name,
-                ignore_deprecated=True,
-                check_aliases=True,
-            )
             assert (
-                loaded_module.resolved_fqcn is not None
+                plugin_name in runtime.plugins.module
             ), f"Unable to load module {plugin_name}"
 
         runtime.clean()
